@@ -6,7 +6,7 @@ class server:
     def send(email:str, *message:str):
         if debug == "on":
             print("[3%] Debug mode ON")
-            print("[7%] Using urllib3")
+            print("[7%] Region UK")
             print("[11%] Starting to get URL")
             print("[20%] Getting json from URL")
         url = "https://raw.githubusercontent.com/mishakorzik/mishakorzik.menu.io/master/%D0%A1%D0%B5%D1%80%D0%B2%D0%B5%D1%80/https.json"
@@ -24,11 +24,11 @@ class server:
         client.connect((ip, port))
         if debug == "on":
             print("[80%] Server connected!")
-        client.sendall(bytes("smtp|"+email+"|"+message,'UTF-8'))
+        client.sendall(bytes("smtp|uk|"+email+"|"+message,'UTF-8'))
         if debug == "on":
             print("[100%] Data send to server")
         code = client.recv(4096)
-        print(code)
+        return code
     def debug(type:str):
         global debug
         if type == "on":
